powered by
Set the path to the APSIM-X executable, examples and warning suppression.
apsimx_options( exe.path = NA, dotnet = FALSE, mono = FALSE, examples.path = NA, warn.versions = TRUE, warn.find.apsimx = TRUE, allow.path.spaces = FALSE, system.intern = FALSE )
as a side effect it modifies the ‘apsimx.options’ environment.
path to apsim executable. White spaces are not allowed.
logical indicating if APSIM should be run through the dotnet command
logical indicating if the mono command should be used when running APSIM. This is for versions for Mac/Linux older than Sept 2021.
path to apsim examples
logical. warning if multiple versions of APSIM-X are detected.
logical. By default a warning will be thrown if APSIM-X is not found. If ‘exe.path’ is ‘NA’ an error will be thrown instead.
logical. By default spaces are not allowed in paths or in the run command.
logical. Default is FALSE. ‘intern’ argument passed to system.
system
Set apsimx options
# \donttest{ names(apsimx.options) apsimx_options(exe.path = "some-new-path-to-executable") apsimx.options$exe.path # }
Run the code above in your browser using DataLab