Learn R Programming

apsimx (version 2.8.271)

get_slga_soil_profile: Generate a synthetic APSIM soil profile from the SLGA soil database

Description

Retrieves soil data from the SLGA database (Australia) and converts it to an APSIM soil_profile object

Usage

get_slga_soil_profile(
  lonlat,
  statistic = c("mean", "Q0.5"),
  soil.profile,
  find.location.name = TRUE,
  fix = FALSE,
  verbose = TRUE,
  check = TRUE,
  physical = c("default", "SR"),
  xargs = NULL
)

Value

it generates an object of class ‘soil_profile’.

Arguments

lonlat

Longitude and latitude vector (e.g. c(151.8306, -27.4969)).

statistic

default is the mean

soil.profile

a soil profile to fill in in case the default one is not appropriate

find.location.name

default is TRUE. Use either maps package or photon API to find Country/State. If you are running this function many times it might be better to set this to FALSE.

fix

whether to fix compatibility between saturation and bulk density (default is FALSE).

verbose

argument passed to the fix function.

check

whether to check the soil profile (default is TRUE)

physical

whether soil physical properties are obtained from the data base or through ‘SR’, Saxton and Rawls pedotransfer functions.

xargs

additional arguments passed to apsimx_soil_profile or ‘apsimx:::approx_soil_variable’ function. At the moment these are: ‘soil.bottom’, ‘method’ and ‘nlayers’.

Author

Fernando E. Miguez, Chloe (Yunru Lai), Eric Zurcher (CSIRO) and Andrew Moore (CSIRO)

Details

Source: https://esoil.io/TERNLandscapes/Public/Pages/SLGA/index.html

See Also

apsimx_soil_profile, edit_apsim_replace_soil_profile, edit_apsimx_replace_soil_profile.

Examples

Run this code
if (FALSE) {
## Get soil profile properties for a single point
  sp1 <- get_slga_soil_profile(lonlat = c(151.8306, -27.4969), fix = TRUE, verbose = FALSE)
  ## Visualize
  plot(sp1)
  plot(sp1, property = "water")
}

Run the code above in your browser using DataLab