grep_json_list: grep but for json list
Description
recursive grep adapted for a json list
Usage
grep_json_list(
pattern,
x,
ignore.case = FALSE,
search.depth = 10,
how = c("unlist", "replace", "list")
)Value
It returns a list with the found object, the json path and the positions in the list.
Arguments
- pattern
as in grep
- x
object (a list)
- ignore.case
as in grep
- search.depth
search depth for the list (to prevent endless search)
- how
argument passed to rapply